==> pyskyqremote-0.2.30b4.tar.gz: pyskyqremote-0.2.30b4/pyskyqremote/const_test.py <==
"""Test constants for pyskyqremote."""


TEST_CHANNEL_LIST = [
    {
        "c": "317",
        "dvbtriplet": "64511.8800.11684",
        "schedule": True,
        "servicetype": "DSAT",
        "servicetypes": ["DSAT"],
        "sf": "hd",
        "sg": 12,
        "sid": "684",
        "sk": 684,
        "t": "Premium Comedy HD",
        "xsg": 3,
    },
    {
        "c": "105",
        "dvbtriplet": "64511.6400.11075",
        "schedule": True,
        "servicetype": "DSAT",
        "servicetypes": ["DSAT"],
        "sf": "hd",
        "sg": 13,
        "sid": "5435",
        "sk": 75,
        "t": "Canale 5 HD",
        "xsg": 4,
    },
    {
        "c": "301",
        "dvbtriplet": "64511.6400.11074",
        "schedule": True,
        "servicetype": "DSAT",
        "servicetypes": ["DSAT"],
        "sf": "hd",
        "sg": 21,
        "sid": "920",
        "sk": 920,
        "t": "Sky Sport Uno",
        "xsg": 1,
    },
    {
        "c": "5472",
        "dvbtriplet": "272.950.5178",
        "servicetype": "DTT",
        "servicetypes": ["DTT"],
        "sf": "hd",
        "sg": 10,
        "sid": "M110-3b6-143a-ffff",
        "t": "Sky Sport Uno HD",
        "xsg": 65535,
    },
    {
        "c": "303",
        "dvbtriplet": "64511.6400.11074",
        "schedule": True,
        "servicetype": "DSAT",
        "servicetypes": ["DSAT"],
        "sf": "hd",
        "sg": 21,
        "sid": "1235",
        "sk": 1235,
        "t": "Sky Cinema Sci-Fi HD",
        "xsg": 1,
    },
    {
        "c": "120",
        "dvbtriplet": "64511.6400.11074",
        "schedule": True,
        "servicetype": "DSAT",
        "servicetypes": ["DSAT"],
        "sf": "hd",
        "sg": 21,
        "sid": "74",
        "sk": 74,
        "t": "Sky Arte HD",
        "xsg": 1,
    },
    {
        "c": "999",
        "dvbtriplet": "64511.6400.11074",
        "schedule": True,
        "servicetype": "DSAT",
        "servicetypes": ["DSAT"],
        "sf": "hd",
        "sg": 21,
        "sid": "99",
        "sk": 99,
        "t": "Fake Channel",
        "xsg": 1,
    },
    {
        "c": "101",
        "dvbtriplet": "2.2048.10353",
        "schedule": True,
        "servicetype": "DSAT",
        "servicetypes": ["DSAT"],
        "sf": "sd",
        "sg": 12,
        "sid": "2153",
        "sk": 2153,
        "t": "BBC One South",
        "xsg": 3,
    },
]

==> pyskyqremote-0.2.35.tar.gz: pyskyqremote-0.2.35/pyskyqremote/const_test.py <==
"""Test constants for pyskyqremote."""


TEST_CHANNEL_LIST = [
    {
        "c": "100",
        "dvbtriplet": "133.2.147",
        "schedule": True,
        "servicetype": "DSAT",
        "servicetypes": ["DSAT"],
        "sf": "hd",
        "sg": 12,
        "sid": "147",
        "sk": 147,
        "startover": True,
        "t": "Sky One HD",
        "xsg": 2,
    },
    {
        "c": "101",
        "dvbtriplet": "133.4.117",
        "schedule": True,
        "servicetype": "DSAT",
        "servicetypes": ["DSAT"],
        "sf": "hd",
        "sg": 12,
        "sid": "117",
        "sk": 117,
        "startover": True,
        "t": "Sky Serien & Shows HD",
        "xsg": 2,
    },
    {
        "c": "105",
        "dvbtriplet": "64511.6400.11075",
        "schedule": True,
        "servicetype": "DSAT",
        "servicetypes": ["DSAT"],
        "sf": "hd",
        "sg": 13,
        "sid": "5435",
        "sk": 75,
        "t": "Canale 5 HD",
        "xsg": 4,
    },
    {
        "c": "301",
        "dvbtriplet": "64511.6400.11074",
        "schedule": True,
        "servicetype": "DSAT",
        "servicetypes": ["DSAT"],
        "sf": "hd",
        "sg": 21,
        "sid": "920",
        "sk": 920,
        "t": "Sky Sport Uno",
        "xsg": 1,
    },
    {
        "c": "5472",
        "dvbtriplet": "272.950.5178",
        "servicetype": "DTT",
        "servicetypes": ["DTT"],
        "sf": "hd",
        "sg": 10,
        "sid": "M110-3b6-143a-ffff",
        "t": "Sky Sport Uno HD",
        "xsg": 65535,
    },
    {
        "c": "303",
        "dvbtriplet": "64511.6400.11074",
        "schedule": True,
        "servicetype": "DSAT",
        "servicetypes": ["DSAT"],
        "sf": "hd",
        "sg": 21,
        "sid": "1235",
        "sk": 1235,
        "t": "Sky Cinema Sci-Fi HD",
        "xsg": 1,
    },
    {
        "c": "120",
        "dvbtriplet": "64511.6400.11074",
        "schedule": True,
        "servicetype": "DSAT",
        "servicetypes": ["DSAT"],
        "sf": "hd",
        "sg": 21,
        "sid": "74",
        "sk": 74,
        "t": "Sky Arte HD",
        "xsg": 1,
    },
    {
        "c": "999",
        "dvbtriplet": "64511.6400.11074",
        "schedule": True,
        "servicetype": "DSAT",
        "servicetypes": ["DSAT"],
        "sf": "hd",
        "sg": 21,
        "sid": "99",
        "sk": 99,
        "t": "Fake Channel",
        "xsg": 1,
    },
]
